require 'spec_helper'
describe 'vim' do

  platforms = {
    'debian6' =>
      { :osfamily => 'Debian',
        :release  => '6',
        :packages => [ 'vim-common', 'vim-nox', 'vim-runtime'],
      },
    'el5' =>
      { :osfamily => 'RedHat',
        :release  => '5',
        :packages => [ 'vim-common', 'vim-enhanced', 'vim-minimal'],
      },
    'el6' =>
      { :osfamily => 'RedHat',
        :release  => '6',
        :packages => [ 'vim-common', 'vim-enhanced', 'vim-minimal'],
      },
    'suse10' =>
      { :osfamily => 'Suse',
        :release  => '10',
        :packages => 'vim',
      },
    'suse11' =>
      { :osfamily => 'Suse',
        :release  => '11',
        :packages => ['vim','vim-base','vim-data'],
      },
  }

  describe 'with default values for parameters on' do
    platforms.sort.each do |k,v|
      context "#{v[:osfamily]} #{v[:release]}" do
        let :facts do
          { :osfamily          => v[:osfamily],
            :lsbmajdistrelease => v[:release],
          }
        end

        it { should compile.with_all_deps }

        it { should contain_class('vim')}

        it {
          should contain_package('vim_packages').with({
            'name'   => v[:packages],
            'ensure' => 'present',
          })
        }

        it {
          should contain_file('root_vimrc').with({
            'ensure' => 'file',
            'path'   => '/.vimrc',
            'owner'  => 'root',
            'group'  => 'root',
            'mode'   => '0644',
          })
        }

        it {
          should contain_file('root_vim_dir').with({
            'ensure' => 'directory',
            'path'   => '/.vim',
            'owner'  => 'root',
            'group'  => 'root',
            'mode'   => '0644',
          })
        }
      end
    end
  end

  describe 'with unsupported' do
    context 'version of Suse' do
      let :facts do
        { :osfamily          => 'Suse',
          :lsbmajdistrelease => '9',
        }
      end

      it 'should fail' do
        expect {
          should contain_class('vim')
        }.to raise_error(Puppet::Error,/^vim supports Suse 10 and 11. Detected lsbmajdistrelease is <9>/)
      end
    end

    context 'osfamily' do
      let :facts do
        { :osfamily          => 'Unsupported',
          :lsbmajdistrelease => '9',
        }
      end

      it 'should fail' do
        expect {
          should contain_class('vim')
        }.to raise_error(Puppet::Error,/^vim supports OS families Debian, RedHat, and Suse. Detected osfamily is <Unsupported>./)
      end
    end
  end
end
